@@ -19,6 +19,7 @@
  */
 
 #include "glomconversions.h"
+#include "../connectionpool.h"
 #include <sstream> //For stringstream
 
 #include <locale>     // for locale, time_put
@@ -153,7 +154,7 @@ Glib::ustring GlomConversions::get_text_for_gda_value(Field::glom_field_type glo
     return "";
   }
 
-  if(glom_type == Field::TYPE_DATE)
+  if( (glom_type == Field::TYPE_DATE) && (value.get_value_type() == Gnome::Gda::VALUE_TYPE_DATE))
   {
     Gnome::Gda::Date gda_date = value.get_date();
 
@@ -170,7 +171,7 @@ Glib::ustring GlomConversions::get_text_for_gda_value(Field::glom_field_type glo
     return date.format_string("%x"); //%x means "is replaced by the locale's appropriate date representation".
     */
   }
-  else if(glom_type == Field::TYPE_TIME)
+  else if((glom_type == Field::TYPE_TIME) && (value.get_value_type() == Gnome::Gda::VALUE_TYPE_TIME))
   {
     Gnome::Gda::Time gda_time = value.get_time();
 
@@ -181,7 +182,7 @@ Glib::ustring GlomConversions::get_text_for_gda_value(Field::glom_field_type glo
 
     return format_time(the_c_time, locale, iso_format);
   }
-  else if(glom_type == Field::TYPE_NUMERIC)
+  else if( (glom_type == Field::TYPE_NUMERIC) && (value.get_value_type() == Gnome::Gda::VALUE_TYPE_NUMERIC))
   {
     const GdaNumeric* gda_numeric = value.get_numeric();
     std::string text_in_c_locale;
@@ -624,7 +625,7 @@ Glib::ustring GlomConversions::util_trim_whitespace(const Glib::ustring& text)
  //Find non-whitespace from back:
   Glib::ustring::size_type posBack = Glib::ustring::npos;
   pos = 0;
-  for(Glib::ustring::reverse_iterator iter = result.rend(); iter != result.rbegin(); ++iter)
+  for(Glib::ustring::reverse_iterator iter = result.rbegin(); iter != result.rend(); ++iter)
   {
     if(!Glib::Unicode::isspace(*iter))
     {
@@ -670,6 +671,11 @@ Glib::ustring util_build_sql_select_with_where_clause(const Glib::ustring& table
         const Relationship relationship = iter->m_relationship;
 
         const Glib::ustring field_table_name = relationship.get_to_table();
+        if(field_table_name.empty())
+        {
+          g_warning("util_build_sql_select_with_where_clause(): field_table_name is null. relationship name = %s", relationship.get_name().c_str());
+        }
+
         sql_part_fields += ( field_table_name + "." );
 
         //Add the relationship to the list:
@@ -703,3 +709,55 @@ Glib::ustring util_build_sql_select_with_where_clause(const Glib::ustring& table
 
   return result;
 }
+
+
+type_list_values_with_second get_choice_values(const LayoutItem_Field& field)
+{
+  type_list_values_with_second list_values;
+
+  Glib::ustring choice_relationship_name, choice_field, choice_second;
+  field.get_choices(choice_relationship_name, choice_field, choice_second);
+
+  const Relationship relationship = field.m_choices_related_relationship;
+  const Glib::ustring to_table = relationship.get_to_table();
+  if(to_table.empty())
+  {
+    g_warning("get_choice_values(): table_name is null. relationship name = %s", field.m_choices_related_relationship.get_name().c_str());
+    return list_values;
+  }
+
+  const bool with_second = !choice_second.empty();
+  const Glib::ustring sql_second = to_table + "." + choice_second;
+
+  //Get possible values from database, sorted by the first column.
+  Glib::ustring sql_query = "SELECT " + to_table + "." + choice_field;
+  if(with_second)
+    sql_query += ", " + sql_second;
+
+  sql_query += " FROM " + relationship.get_to_table() + " ORDER BY " + to_table + "." + choice_field;
+
+  //Connect to database:
+  sharedptr<SharedConnection> connection = ConnectionPool::get_instance()->connect();
+
+
+  std::cout << "get_choice_values: Executing SQL: " << sql_query << std::endl;
+  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = connection->get_gda_connection()->execute_single_command(sql_query);
+
+  if(datamodel)
+  {
+    guint count = datamodel->get_n_rows();
+    for(guint row = 0; row < count; ++row)
+    {
+      std::pair<Gnome::Gda::Value, Gnome::Gda::Value> itempair;
+      itempair.first = datamodel->get_value_at(0, row);
+
+      if(with_second)
+        itempair.second = datamodel->get_value_at(1, row);
+
+      list_values.push_back(itempair);
+    }
+  }
+
+  return list_values;
+}
+
