@@ -96,7 +96,7 @@ main(int argc, char* argv[])
     Glib::ustring input_uri = group.m_arg_filename;
 
     //debugging:
-    input_uri = "file:///home/murrayc/cvs/gnome212/glom/examples/example_smallbusiness.glom";
+    //input_uri = "file:///home/murrayc/cvs/gnome212/glom/examples/example_smallbusiness.glom";
 
 
     // Main app
