@@ -33,29 +33,35 @@ Box_Data::Box_Data()
   m_pDialogLayout(0)
 {
   m_bUnstoredData = false;
-   
 
-    
   //Connect signals:
   m_Button_Find.signal_clicked().connect(sigc::mem_fun(*this, &Box_Data::on_Button_Find));
 }
 
 Box_Data::~Box_Data()
 {
+  if(m_pDialogLayout)
+  {
+    remove_view(m_pDialogLayout);
+    delete m_pDialogLayout;
+  }
 }
 
 void Box_Data::init_db_details(const Glib::ustring& strTableName, const Glib::ustring& strWhereClause)
 {
+  m_strTableName = strTableName;
   m_strWhereClause = strWhereClause;
 
-  Box_DB_Table::init_db_details(strTableName);
+  create_layout(); //So that fill_from_database() can succeed.
+
+  Box_DB_Table::init_db_details(strTableName); //Calls fill_from_database().
 }
 
-void Box_Data::refresh_db_details(const Glib::ustring& strWhereClause)
+void Box_Data::refresh_data_from_database(const Glib::ustring& strWhereClause)
 {
   m_strWhereClause = strWhereClause;
 
-  Box_DB_Table::refresh_db_details();
+  Box_DB_Table::refresh_data_from_database(); //Calls fill_from_database().
 }
 
 Glib::ustring Box_Data::get_WhereClause() const
@@ -63,7 +69,7 @@ Glib::ustring Box_Data::get_WhereClause() const
   Glib::ustring strClause;
 
   //Look at each field entry and build e.g. 'Name = "Bob"'
-  for(type_vecLayoutFields::const_iterator iter = m_Fields.begin(); iter != m_Fields.end(); ++iter)
+  for(type_vecLayoutFields::const_iterator iter = m_FieldsShown.begin(); iter != m_FieldsShown.end(); ++iter)
   {
     Glib::ustring strClausePart;
 
@@ -120,7 +126,6 @@ Box_Data::type_map_fields Box_Data::get_record_field_values(const Gnome::Gda::Va
     for(Document_Glom::type_vecFields::const_iterator iter = fields.begin(); iter != fields.end(); ++iter)
     {
       LayoutItem_Field layout_item;
-      layout_item.set_name(iter->get_name());
       layout_item.m_field = *iter;
       fieldsToGet.push_back(layout_item);
     }
@@ -154,26 +159,31 @@ Glib::RefPtr<Gnome::Gda::DataModel> Box_Data::record_new(bool use_entered_data,
 
   const Glib::ustring primary_key_name = fieldPrimaryKey.get_name();
 
-  type_vecLayoutFields fieldsToAdd = m_Fields;
+  type_vecLayoutFields fieldsToAdd = m_FieldsShown;
 
-  //Add the primary key if it is not normally shown:
-  type_vecLayoutFields::const_iterator iterFindPrimary = std::find_if(fieldsToAdd.begin(), fieldsToAdd.end(), predicate_FieldHasName<LayoutItem_Field>(primary_key_name));
-  if(iterFindPrimary == fieldsToAdd.end())
+  //Add values for all fields, not just the shown ones:
+  //For instance, we must always add the primary key, and fields with default/calculated/lookup values:
+  for(type_vecFields::const_iterator iter = m_TableFields.begin(); iter != m_TableFields.end(); ++iter)
   {
-    LayoutItem_Field layout_item;
-    layout_item.set_name(primary_key_name);
-    layout_item.m_field = fieldPrimaryKey;
+    //TODO: Search for the non-related field with the name, not just the field with the name:
+    type_vecLayoutFields::const_iterator iterFind = std::find_if(fieldsToAdd.begin(), fieldsToAdd.end(), predicate_FieldHasName<LayoutItem_Field>(iter->get_name()));
+    if(iterFind == fieldsToAdd.end())
+    {
+      LayoutItem_Field layout_item;
+      layout_item.m_field = *iter;
 
-    fieldsToAdd.push_back(layout_item);
+      fieldsToAdd.push_back(layout_item);
+    }
   }
 
   //Calculate any necessary field values and enter them:
-  for(type_vecLayoutFields::const_iterator iter = m_Fields.begin(); iter != m_Fields.begin(); ++iter)
+  for(type_vecLayoutFields::const_iterator iter = fieldsToAdd.begin(); iter != fieldsToAdd.end(); ++iter)
   {
     const LayoutItem_Field& layout_item = *iter;
 
     //If the user did not enter something in this field:
     Gnome::Gda::Value value = get_entered_field_data(layout_item);
+
     if(GlomConversions::value_is_empty(value)) //This deals with empty strings too.
     {
       const Field& field = layout_item.m_field;
@@ -184,9 +194,22 @@ Glib::RefPtr<Gnome::Gda::DataModel> Box_Data::record_new(bool use_entered_data,
       {
         const type_map_fields field_values = get_record_field_values(primary_key_value);
 
-        Gnome::Gda::Value value = glom_evaluate_python_function_implementation(field.get_glom_type(), calculation, field_values);
+        const Gnome::Gda::Value value = glom_evaluate_python_function_implementation(field.get_glom_type(), calculation, field_values,
+          get_document(), m_strTableName);
         set_entered_field_data(layout_item, value);
       }
+
+      //Use default values (These are also specified in postgres as part of the field definition,
+      //so we could theoretically just not specify it here.
+      //TODO_Performance: Add has_default_value()?
+      if(GlomConversions::value_is_empty(value))
+      {
+        const Gnome::Gda::Value default_value = field.get_default_value();
+        if(!GlomConversions::value_is_empty(default_value))
+        {
+          set_entered_field_data(layout_item, default_value);
+        }
+      }
     }
   }
 
@@ -261,6 +284,14 @@ bool Box_Data::get_unstored_data() const
   return m_bUnstoredData;
 }
 
+void Box_Data::create_layout()
+{
+  set_unstored_data(false);
+
+  //Cache the table information, for performance:
+  m_TableFields = get_fields_for_table(m_strTableName);
+}
+
 void Box_Data::fill_from_database()
 {
   set_unstored_data(false);
@@ -290,7 +321,7 @@ void Box_Data::show_layout_dialog()
 {
   if(m_pDialogLayout)
   {
-    m_pDialogLayout->set_document(m_layout_name, get_document(), m_strTableName, m_Fields);
+    m_pDialogLayout->set_document(m_layout_name, get_document(), m_strTableName, m_FieldsShown); //TODO: Use m_TableFields?
     m_pDialogLayout->show();
   }
 }
@@ -298,6 +329,7 @@ void Box_Data::show_layout_dialog()
 void Box_Data::on_dialog_layout_hide()
 {
   //Re-fill view, in case the layout has changed:
+  create_layout();
   fill_from_database();
 }
 
@@ -423,7 +455,6 @@ Box_Data::type_vecLayoutFields Box_Data::get_table_fields_to_show(const Glib::us
       if(bPrimaryKeyFound)
       {
         LayoutItem_Field layout_item;
-        layout_item.set_name(primary_key_field_name);
         layout_item.m_field = all_fields[iPrimaryKey];
 
         //Don't use thousands separators with ID numbers:
@@ -446,7 +477,6 @@ Box_Data::type_vecLayoutFields Box_Data::get_table_fields_to_show(const Glib::us
         if(iter->get_name() != primary_key_field_name) //We already added the primary key.
         {
           LayoutItem_Field layout_item;
-          layout_item.set_name(iter->get_name());
           layout_item.m_field = field_info;
 
           layout_item.set_editable(true); //A sensible default.
@@ -512,7 +542,7 @@ Gnome::Gda::Value Box_Data::generate_next_auto_increment(const Glib::ustring& ta
   return GlomConversions::parse_value(result);
 }
 
-/** Get the fields that are in related tables, via a relationship using @a field_name changes.
+/** Get the shown fields that are in related tables, via a relationship using @a field_name changes.
  */
 Box_Data::type_vecLayoutFields Box_Data::get_related_fields(const Glib::ustring& field_name) const
 {
@@ -521,7 +551,7 @@ Box_Data::type_vecLayoutFields Box_Data::get_related_fields(const Glib::ustring&
   const Document_Glom* document = dynamic_cast<const Document_Glom*>(get_document());
   if(document)
   {
-    for(type_vecLayoutFields::const_iterator iter = m_Fields.begin(); iter != m_Fields.end();  ++iter)
+    for(type_vecLayoutFields::const_iterator iter = m_FieldsShown.begin(); iter != m_FieldsShown.end();  ++iter)
     {
       const LayoutItem_Field& layout_field = *iter;
       //Examine each field that looks up its data from a relationship:
@@ -553,16 +583,21 @@ Box_Data::type_vecLayoutFields Box_Data::get_calculated_fields(const Glib::ustri
   const Document_Glom* document = dynamic_cast<const Document_Glom*>(get_document());
   if(document)
   {
-    //TODO: examine all fields, not just the the shown fields (m_Fields):
-    for(type_vecLayoutFields::const_iterator iter = m_Fields.begin(); iter != m_Fields.end();  ++iter)
+    //Examine all fields, not just the the shown fields.
+    for(type_vecFields::const_iterator iter = m_TableFields.begin(); iter != m_TableFields.end();  ++iter)
     {
-      const Field& field = iter->m_field;
+      const Field& field = *iter;
 
       //Does this field's calculation use the field?
       const Field::type_list_strings fields_triggered = field.get_calculation_fields();
       Field::type_list_strings::const_iterator iterFind = std::find(fields_triggered.begin(), fields_triggered.end(), field_name);
       if(iterFind != fields_triggered.end())
-        result.push_back(*iter);
+      {
+        LayoutItem_Field layout_item;
+        layout_item.m_field = field;
+
+        result.push_back(layout_item);
+      }
     }
   }
 
@@ -579,10 +614,11 @@ Box_Data::type_list_lookups Box_Data::get_lookup_fields(const Glib::ustring& fie
   const Document_Glom* document = dynamic_cast<const Document_Glom*>(get_document());
   if(document)
   {
-    //TODO: examine all fields, not just the the shown fields (m_Fields):
-    for(type_vecLayoutFields::const_iterator iter = m_Fields.begin(); iter != m_Fields.end();  ++iter)
+    //Examine all fields, not just the the shown fields (m_Fields):
+    for(type_vecFields::const_iterator iter = m_TableFields.begin(); iter != m_TableFields.end();  ++iter)
     {
-      const Field& field = iter->m_field;
+      const Field& field = *iter;
+
       //Examine each field that looks up its data from a relationship:
       if(field.get_is_lookup())
       {
@@ -596,7 +632,6 @@ Box_Data::type_list_lookups Box_Data::get_lookup_fields(const Glib::ustring& fie
           {
             //Add it:
             LayoutItem_Field item;
-            item.set_name(field.get_name());
             item.m_field = field;
             result.push_back( type_pairFieldTrigger(item, relationship) );
           }
@@ -636,26 +671,50 @@ Gnome::Gda::Value Box_Data::get_lookup_value(const Relationship& relationship, c
 
 void Box_Data::do_calculations(const LayoutItem_Field& field_changed, const Field& primary_key, const Gnome::Gda::Value& primary_key_value)
 {
+  //TODO: Get (recursively) the list of fields to recalcualte, sort them in order of dependency, then calculate them all.
+
+  //g_warning("Box_Data::do_calculations(): field_changed=%s", field_changed.get_name().c_str());
+
   //TODO_Performance: This is profoundly inefficient:
 
   //Recalculate fields that are triggered by a change of this field's value:
   const type_vecLayoutFields calculated_fields = get_calculated_fields(field_changed.get_name());
   for(type_vecLayoutFields::const_iterator iter = calculated_fields.begin(); iter != calculated_fields.end(); ++iter)
   {
-    //recalculate:
-     const type_map_fields field_values = get_record_field_values(primary_key_value);
-     Gnome::Gda::Value value = glom_evaluate_python_function_implementation(iter->m_field.get_glom_type(), iter->m_field.get_calculation(), field_values);
+    const LayoutItem_Field& field = *iter;
 
-    //show it:
-    set_entered_field_data(*iter, value);
+    type_vecLayoutFields::const_iterator iterFind = std::find(m_FieldsCalculationInProgress.begin(), m_FieldsCalculationInProgress.end(), field);
+    if(iterFind != m_FieldsCalculationInProgress.end())
+    {
+      g_warning("Box_Data::do_calculations(): Circular calculation detected. The Infinite loop was prevented before re-calculating field %s", field.get_name().c_str());
+    }
+    else
+    {
+      //g_warning("CircularPrevention: recalculating field=%s", field.get_name().c_str());
 
-    //Add it to the database (even if it is not shown in the view)
-    set_field_value_in_database(*iter, value, primary_key, primary_key_value);
+      //recalculate:
+      const type_map_fields field_values = get_record_field_values(primary_key_value);
+      Gnome::Gda::Value value = glom_evaluate_python_function_implementation(field.m_field.get_glom_type(), iter->m_field.get_calculation(), field_values,
+            get_document(), m_strTableName);
+
+      //show it:
+      set_entered_field_data(*iter, value);
+
+      //Add it to the database (even if it is not shown in the view)
+      set_field_value_in_database(*iter, value, primary_key, primary_key_value); //This triggers other recalculations/lookups.
+    }
   }
 }
 
-void Box_Data::set_field_value_in_database(const LayoutItem_Field& field_layout, const Gnome::Gda::Value& field_value, const Field& primary_key, const Gnome::Gda::Value& primary_key_value)
+bool Box_Data::set_field_value_in_database(const LayoutItem_Field& field_layout, const Gnome::Gda::Value& field_value, const Field& primary_key_field, const Gnome::Gda::Value& primary_key_value)
 {
+  return set_field_value_in_database(Gtk::TreeModel::iterator(), field_layout, field_value, primary_key_field, primary_key_value);
+}
+
+bool Box_Data::set_field_value_in_database(const Gtk::TreeModel::iterator& row, const LayoutItem_Field& field_layout, const Gnome::Gda::Value& field_value, const Field& primary_key_field, const Gnome::Gda::Value& primary_key_value)
+{
+  //row is invalid, and ignored, for Box_Data_Details.
+
   const Field& field = field_layout.m_field;
 
   const Glib::ustring field_name = field_layout.get_name();
@@ -663,9 +722,38 @@ void Box_Data::set_field_value_in_database(const LayoutItem_Field& field_layout,
   {
     Glib::ustring strQuery = "UPDATE " + m_strTableName;
     strQuery += " SET " + field_name + " = " + field.sql(field_value);
-    strQuery += " WHERE " + primary_key.get_name() + " = " + primary_key.sql(primary_key_value);
-    Query_execute(strQuery);  //TODO: Handle errors
+    strQuery += " WHERE " + primary_key_field.get_name() + " = " + primary_key_field.sql(primary_key_value);
+    Glib::RefPtr<Gnome::Gda::DataModel> datamodel = Query_execute(strQuery);  //TODO: Handle errors
+    if(!datamodel)
+    {
+      g_warning("Box_Data::set_field_value_in_database(): UPDATE failed.");
+      return false; //failed.
+    }
+
+    //Get-and-set values for lookup fields, if this field triggers those relationships:
+    do_lookups(row, field_layout, field_value, primary_key_field, primary_key_value);
+
+    //Update related fields, if this field is used in the relationship:
+    refresh_related_fields(row, field_layout, field_value, primary_key_field, primary_key_value);
+
+    //Calculate any dependent fields.
+    //TODO: Make lookups part of this?
+    //Prevent circular calculations during the recursive do_calculations:
+    {
+      m_FieldsCalculationInProgress.push_back(field_layout);
+
+      //Recalculate any calculated fields that depend on this calculated field.
+      do_calculations(field_layout, primary_key_field, primary_key_value);
+
+      type_vecLayoutFields::iterator iterFind = std::find(m_FieldsCalculationInProgress.begin(), m_FieldsCalculationInProgress.end(), field_layout);
+      if(iterFind != m_FieldsCalculationInProgress.end())
+      {
+        m_FieldsCalculationInProgress.erase(iterFind);
+      }
+    }
   }
+
+  return true;
 }
 
 Document_Glom::type_mapLayoutGroupSequence Box_Data::get_data_layout_groups(const Glib::ustring& layout)
@@ -763,7 +851,7 @@ bool Box_Data::get_field_primary_key_index(const type_vecFields& fields, guint&
   guint cols_count = fields.size();
   while(col < cols_count)
   {
-    if(fields[col].get_field_info().get_primary_key())
+    if(fields[col].get_primary_key())
     {
       field_column = col;
       return true;
@@ -788,7 +876,7 @@ bool Box_Data::get_field_primary_key_index(const type_vecLayoutFields& fields, g
   guint cols_count = fields.size();
   while(col < cols_count)
   {
-    if(fields[col].m_field.get_field_info().get_primary_key())
+    if(fields[col].m_field.get_primary_key())
     {
       field_column = col;
       return true;
@@ -817,10 +905,12 @@ bool Box_Data::record_delete(const Gnome::Gda::Value& primary_key_value)
   }
 }
 
+/*
 bool Box_Data::get_field(const Glib::ustring& name, Field& field) const
 {
-  type_vecLayoutFields::const_iterator iterFind = std::find_if( m_Fields.begin(), m_Fields.end(), predicate_FieldHasName<LayoutItem_Field>(name) );
-  if(iterFind != m_Fields.end()) //If it was found:
+g_warning("debug: Box_Data::get_field()");
+  type_vecFields::const_iterator iterFind = std::find_if( m_TableFields.begin(), m_TableFields.end(), predicate_FieldHasName<LayoutItem_Field>(name) );
+  if(iterFind != m_FieldsShown.end()) //If it was found:
   {
     field = iterFind->m_field;
     return true;
@@ -830,6 +920,7 @@ bool Box_Data::get_field(const Glib::ustring& name, Field& field) const
     return false; //not found.
   }
 }
+*/
 
 Glib::ustring Box_Data::build_sql_select(const Glib::ustring& table_name, const type_vecLayoutFields& fieldsToGet, const Field& primary_key_field, const Gnome::Gda::Value& primary_key_value)
 {
@@ -907,7 +998,7 @@ Glib::ustring Box_Data::build_sql_select_with_where_clause(const Glib::ustring&
 }
 */
 
-Glib::ustring Box_Data::get_layout_item_table_name(const LayoutItem_Field& layout_item, const Glib::ustring table_name)
+Glib::ustring Box_Data::get_layout_item_table_name(const LayoutItem_Field& layout_item, const Glib::ustring& table_name)
 {
   if(!layout_item.get_has_relationship_name())
     return table_name;
@@ -975,7 +1066,7 @@ bool Box_Data::add_related_record_for_field(const LayoutItem_Field& layout_item_
     }
     else
     {
-      const bool key_is_auto_increment = primary_key_field.get_field_info().get_auto_increment();
+      const bool key_is_auto_increment = primary_key_field.get_auto_increment();
 
       //If we would have to set an otherwise auto-increment key to add the record.
       if( key_is_auto_increment && !GlomConversions::value_is_empty(primary_key_value) )
