@@ -24,14 +24,24 @@
 #include "../box_db_table.h"
 #include "dialog_layout.h"
 
+
+/** Call init_db_details() to create the layout and fill it with data from the database.
+ * Call refresh_data_from_database() to fill the existing layout with up-to-date data from the database.
+ *
+ * Derived classes should implement create_layout() to create/arrange the widgets for the groups, fields, portals, etc.
+ * Derived classes should implement fill_from_database() to get the data from the database and fill the widgets created by create_layout().
+ */
 class Box_Data : public Box_DB_Table
 {
 public: 
   Box_Data();
   virtual ~Box_Data();
 
+  ///Create the layout for the database structure, and fill it with data from the database.
   virtual void init_db_details(const Glib::ustring& strTableName, const Glib::ustring& strWhereClause = Glib::ustring());
-  virtual void refresh_db_details(const Glib::ustring& strWhereClause = Glib::ustring());
+
+  //Fill the existing layout with data from the databse.
+  virtual void refresh_data_from_database(const Glib::ustring& strWhereClause = Glib::ustring());
 
   virtual void print_layout(); //A test, for now.
 
@@ -57,8 +67,18 @@ public:
   virtual void on_dialog_layout_hide();
 
 protected:
+
+  /* Create the layout based on the database structure and saved layout,
+   * so that fill_from_database() can fill it with data.
+   */
+  virtual void create_layout();
+
+  ///Fill the existing layout with data from the database.
   virtual void fill_from_database(); //override.
 
+  virtual void do_lookups(const Gtk::TreeModel::iterator& row, const LayoutItem_Field& field_changed, const Gnome::Gda::Value& field_value, const Field& primary_key, const Gnome::Gda::Value& primary_key_value) = 0;
+  virtual void refresh_related_fields(const Gtk::TreeModel::iterator& row, const LayoutItem_Field& field_changed, const Gnome::Gda::Value& field_value, const Field& primary_key, const Gnome::Gda::Value& primary_key_value) = 0;
+
   virtual type_vecLayoutFields get_fields_to_show() const;
   virtual Glib::ustring build_sql_select(const Glib::ustring& table_name, const type_vecLayoutFields& fieldsToGet, const Field& primary_key_field, const Gnome::Gda::Value& primary_key_value);
   //virtual Glib::ustring build_sql_select_with_where_clause(const Glib::ustring& table_name, const type_vecLayoutFields& fieldsToGet, const Glib::ustring& where_clause);
@@ -95,7 +115,8 @@ protected:
   Gnome::Gda::Value get_lookup_value(const Relationship& relationship, const Field& source_field, const Gnome::Gda::Value & key_value);
 
   virtual void do_calculations(const LayoutItem_Field& field_changed, const Field& primary_key, const Gnome::Gda::Value& primary_key_value);
-  void set_field_value_in_database(const LayoutItem_Field& field_layout, const Gnome::Gda::Value& field_value, const Field& primary_key, const Gnome::Gda::Value& primary_key_value);
+  bool set_field_value_in_database(const LayoutItem_Field& field_layout, const Gnome::Gda::Value& field_value, const Field& primary_key, const Gnome::Gda::Value& primary_key_value);
+  bool set_field_value_in_database(const Gtk::TreeModel::iterator& row, const LayoutItem_Field& field_layout, const Gnome::Gda::Value& field_value, const Field& primary_key, const Gnome::Gda::Value& primary_key_value);
 
   virtual bool record_delete(const Gnome::Gda::Value& primary_key_value);
   virtual Glib::RefPtr<Gnome::Gda::DataModel> record_new(bool use_entered_data = true, const Gnome::Gda::Value& primary_key_value = Gnome::Gda::Value()); //New record with all entered field values.
@@ -103,10 +124,10 @@ protected:
 
   virtual bool get_field_primary_key(Field& field) const = 0;
   virtual Gnome::Gda::Value get_primary_key_value_selected() = 0;
-  virtual bool get_field(const Glib::ustring& name, Field& field) const;
+  //virtual bool get_field(const Glib::ustring& name, Field& field) const;
 
   ///Get the table name. It's either the current table or the relationship's to_table:
-  Glib::ustring get_layout_item_table_name(const LayoutItem_Field& layout_item, const Glib::ustring table_name);
+  Glib::ustring get_layout_item_table_name(const LayoutItem_Field& layout_item, const Glib::ustring& table_name);
 
   //Signal handlers:
   virtual void on_Button_Find(); //only used by _Find sub-classes. Should be MI.
@@ -131,7 +152,10 @@ protected:
 
   Glib::ustring m_strWhereClause;
 
-  type_vecLayoutFields m_Fields;
+  type_vecFields m_TableFields; //A cache, so we don't have to repeatedly get them from the Document.
+  type_vecLayoutFields m_FieldsShown; //And any extra keys needed by shown fields.
+
+  type_vecLayoutFields m_FieldsCalculationInProgress; //Prevent circular calculations.
 };
 
 #endif
