@@ -25,7 +25,6 @@
 Dialog_Layout::Dialog_Layout(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
 : Gtk::Dialog(cobject),
   m_entry_table_title(0),
-  m_document(0),
   m_modified(false)
 {
   Gtk::Button* button = 0;
@@ -42,12 +41,12 @@ Dialog_Layout::~Dialog_Layout()
 {
 }
 
-void Dialog_Layout::set_document(const Glib::ustring& layout, Document_Glom* document, const Glib::ustring& table_name, const type_vecLayoutFields& /* table_fields */)
+void Dialog_Layout::set_document(const Glib::ustring& layout, Document_Glom* /* document */, const Glib::ustring& table_name, const type_vecLayoutFields& /* table_fields */)
 {
   m_modified = false;
 
   m_layout_name = layout; 
-  m_document = document;
+  //m_document = document;
   m_table_name = table_name;
 
   m_modified = false;
